<TS language="cy" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>Clic-dde i olygu cyfeiriad neu label</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>Creu cyfeiriad newydd</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Newydd</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Copio'r cyfeiriad sydd wedi'i ddewis i'r clipfwrdd system</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Copïo</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>C&amp;au</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Dileu'r cyfeiriad presennol wedi ei ddewis o'r rhestr</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation>Cyfeiriad neu label i chwilio</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Allforio'r data yn y tab presennol i ffeil</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Allforio</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Dileu</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>Dewis y cyfeiriad i yrru'r arian</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>Dewis y cyfeiriad i dderbyn arian</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>D&amp;ewis</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>Anfon cyfeiriadau</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>Derbyn cyfeiriadau</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>Rhain ydi eich cyfeiriadau Bitcoin ar gyfer gyrru taliadau. Gwnewch yn sicr o'r swm a'r cyfeiriad derbyn cyn gyrru arian.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp;Copïo Cyfeiriad</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Copïo &amp;Label</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Golygu</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>Allforio Rhestr Cyfeiriadau</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Methiant Allforio</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>Roedd camgymeriad yn trïo safio'r rhestr gyfeiriadau i'r %1. Triwch eto os gwelwch yn dda.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Label</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Cyfeiriad</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(dim label)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Deialog Cyfrinair</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Teipiwch gyfrinymadrodd</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Cyfrinymadrodd newydd</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Ailadroddwch gyfrinymadrodd newydd</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Amgryptio'r Waled</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Mae'r weithred hon angen eich cyfrinair waled i ddatgloi'r waled.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Datgloi'r waled</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>Mae'r weithred hon angen eich cyfrinair waled i ddatgryptio'r waled.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>Datgryptio waled</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Newid cyfrinair</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Cadarnhau amgryptio'r waled</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation>Rhybudd: Os ydych yn amgryptio'r waled ag yn colli'r cyfrinair, byddwch yn &lt;b&gt; COLLI EICH BITCOINS I GYD &lt;b&gt; !</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Ydych yn siwr eich bod eisiau amgryptio eich waled?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Waled wedi amgryptio</translation>
    </message>
    <message>
        <source>Wallet to be encrypted</source>
        <translation>Waled i'w amgryptio</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>PWYSIG: Mi ddylai unrhyw back ups blaenorol rydych wedi ei wneud o ffeil eich waled gael ei ddiweddaru efo'r ffeil amgryptiedig newydd ei chreu. Am resymau diogelwch, bydd back ups blaenorol o ffeil y walet heb amgryptio yn ddiwerth mor fuan ac yr ydych yn dechrau defnyddio'r waled amgryptiedig newydd.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Amgryptio waled wedi methu</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Amgryptio waled wedi methu oherwydd gwall mewnol. Dydi eich waled heb amgryptio.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Nid ydi'r cyfrineiriau a gyflenwyd yn cyfateb.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Dadgloi waled wedi methu</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Mae'r cyfrinair ysgrifennwyd ar gyfer datgryptio'r waled yn anghywir.</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>Amgryptio waled wedi methu</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Newid cyfrinair waled yn llwyddiannus.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Rhybudd: Mae allwedd Caps Lock ymlaen!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation>IP/Rhwydfwgwd</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation>Gwaharddwyd Nes</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Arwyddo &amp;neges...</translation>
    </message>
    <message>
        <source>Synchronizing with network...</source>
        <translation>Cysoni â'r rhwydwaith...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Trosolwg</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Dangos trosolwg cyffredinol y waled</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;Trafodion</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Pori hanes trafodion</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>A&amp;llanfa</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Gadael rhaglen</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation>&amp;Ynghylch %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation>Dangos gwybodaeth am %1</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Ynghylch &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>Dangos gwybodaeth am Qt</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Opsiynau</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation>Addasu ffurfweddiad dewisiadau ar gyfer %1</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Amgryptio'r waled...</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet...</source>
        <translation>&amp;Backup Waled...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Newid cyfrinymadrodd...</translation>
    </message>
    <message>
        <source>Open &amp;URI...</source>
        <translation>Agor &amp;URI...</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation>Waled:</translation>
    </message>
    <message>
        <source>Click to disable network activity.</source>
        <translation>Cliciwch i anablu gweithgaredd y rhwydwaith.</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <translation>Gweithgaredd rhwydwaith wedi anablu.</translation>
    </message>
    <message>
        <source>Click to enable network activity again.</source>
        <translation>Cliciwch i alluogi gweithgaredd y rhwydwaith eto.</translation>
    </message>
    <message>
        <source>Syncing Headers (%1%)...</source>
        <translation>Syncio pennawdau (%1%)...</translation>
    </message>
    <message>
        <source>Reindexing blocks on disk...</source>
        <translation>Ailfynegi y blociau ar ddisg...</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation>Anfon arian i gyfeiriad Bitcoin</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation>Bacio fyny'r waled i leoliad arall</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Newid y cyfrinair ddefnyddiwyd ar gyfer amgryptio'r waled</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>&amp;Di fygio'r ffenest</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Gwirio neges...</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Anfon</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Derbyn</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Dangos / Cuddio</translation>
    </message>
    <message>
        <source>Show or hide the main Window</source>
        <translation>Dangos neu guddio y brif Ffenest</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation>Amgryptio'r allweddi preifat sy'n perthyn i'ch waled</translation>
    </message>
    <message>
        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
        <translation>Arwyddo negeseuon gyda eich cyfeiriadau Bitcoin i brofi mae chi sy'n berchen arnynt</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
        <translation>Gwirio negeseuon i sicrhau eu bod wedi eu harwyddo gyda cyfeiriadau Bitcoin penodol</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Ffeil</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Gosodiadau</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Cymorth</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation>Bar offer tabiau</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and bitcoin: URIs)</source>
        <translation>Gofyn taliadau (creu côd QR a bitcoin: URIs)</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation>Dangos rhestr o gyfeiriadau danfon a labelau wedi eu defnyddio</translation>
    </message>
    <message>
        <source>Show the list of used receiving addresses and labels</source>
        <translation>Dangos rhestr o gyfeiriadau derbyn a labelau wedi eu defnyddio</translation>
    </message>
    <message>
        <source>Open a bitcoin: URI or payment request</source>
        <translation>Agor Bitcoin: URI neu ofyn taliad</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation>&amp;Dewisiadau Gorchymyn-llinell</translation>
    </message>
    <message>
        <source>Indexing blocks on disk...</source>
        <translation>Mynegai'r blociau ar ddisg...</translation>
    </message>
    <message>
        <source>Processing blocks on disk...</source>
        <translation>Prosesu blociau ar ddisg...</translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation>%1 Tu ôl</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation>Cafodd y bloc olaf i'w dderbyn ei greu %1 yn ôl.</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation>Ni fydd trafodion ar ôl hyn yn weledol eto.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Gwall</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Rhybudd</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Gwybodaeth</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Cyfamserol</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <translation>Agor Waled</translation>
    </message>
    <message>
        <source>Open a wallet</source>
        <translation>Agor waled</translation>
    </message>
    <message>
        <source>Close Wallet...</source>
        <translation>Cau Waled...</translation>
    </message>
    <message>
        <source>Close wallet</source>
        <translation>Cau waled</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Ffenestr</translation>
    </message>
    <message>
        <source>Connecting to peers...</source>
        <translation>Cysylltu efo cyfoedion...</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Dal i fyny...</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation> Gwall: %1</translation>
    </message>
    <message>
        <source>Warning: %1</source>
        <translation>Rhybudd: %1</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation>Dyddiad: %1
</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation>Cyfanswm: %1
</translation>
    </message>
    <message>
        <source>Wallet: %1
</source>
        <translation>Waled: %1
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation>Math: %1
</translation>
    </message>
    <message>
        <source>Label: %1
</source>
        <translation>Label: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation>Cyfeiriad: %1
</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Trafodiad anfonwyd</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Trafodiad sy'n cyrraedd</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;enabled&lt;/b&gt;</source>
        <translation>Cynhyrchu allweddi HD wedi ei &lt;b&gt; alluogi &lt;/b&gt;</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;disabled&lt;/b&gt;</source>
        <translation>Cynhyrchu allweddi HD wedi'w &lt;b&gt; anablu &lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation>Mae'r waled &lt;b&gt;wedi'i amgryptio&lt;/b&gt; ac &lt;b&gt;heb ei gloi&lt;/b&gt; ar hyn o bryd</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Mae'r waled &lt;b&gt;wedi'i amgryptio&lt;/b&gt; ac &lt;b&gt;ar glo&lt;/b&gt; ar hyn o bryd</translation>
    </message>
    <message>
        <source>A fatal error occurred. Bitcoin can no longer continue safely and will quit.</source>
        <translation>Mae gwall angheuol wedi digwydd. Ni all Bitcoin barhau'n ddiogel ac mae'n cau lawr.</translation>
    </message>
</context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Coin Selection</source>
        <translation>Dewis Ceiniog</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Maint:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Maint:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Cyfanswm:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Ffî:</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>Llwch:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Ar Ôl Ffî:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Newid:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Cyfanswm</translation>
    </message>
    <message>
        <source>Received with label</source>
        <translation>Derbynwyd gyda label</translation>
    </message>
    <message>
        <source>Received with address</source>
        <translation>Derbynwyd gyda chyfeiriad</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dyddiad</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Cadarnhadiadau</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Cadarnhawyd</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Copïo cyfeiriad</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Copïo label</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Copïo cyfanswm</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(dim label)</translation>
    </message>
    </context>
<context>
    <name>CreateWalletActivity</name>
    </context>
<context>
    <name>CreateWalletDialog</name>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Golygu'r cyfeiriad</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Label</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Cyfeiriad</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>name</source>
        <translation>enw</translation>
    </message>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation>Croeso</translation>
    </message>
    <message>
        <source>Bitcoin</source>
        <translation>Bitcoin</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Gwall</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Form</source>
        <translation>Ffurflen</translation>
    </message>
    </context>
<context>
    <name>OpenURIDialog</name>
    <message>
        <source>Open URI</source>
        <translation>Agor URI</translation>
    </message>
    <message>
        <source>URI:</source>
        <translation>URI:</translation>
    </message>
    </context>
<context>
    <name>OpenWalletActivity</name>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opsiynau</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Rhwydwaith</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation>W&amp;aled</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Tor</source>
        <translation>Tor</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Ffenestr</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Dangos</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Gwall</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Ffurflen</translation>
    </message>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>Cyfanswm</translation>
    </message>
    <message>
        <source>%1 and %2</source>
        <translation>%1 a %2</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation> Gwall: %1</translation>
    </message>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Information</source>
        <translation>Gwybodaeth</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Rhwydwaith</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Agor</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Label:</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Copïo label</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Copïo Cyfanswm</translation>
    </message>
</context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Copy &amp;Address</source>
        <translation>&amp;Cyfeiriad Copi</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Cyfeiriad</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Cyfanswm</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Label</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Waled</translation>
    </message>
</context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>Dyddiad</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Label</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(dim label)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Anfon arian</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Maint:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Maint</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Maint</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Ffi</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Ar Ôl Ffî</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Newid:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Anfon at pobl lluosog ar yr un pryd</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>Llwch</translation>
    </message>
    <message>
        <source>Balance:</source>
        <translation>Gweddill:</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Cadarnhau'r gweithrediad anfon</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Copïo Cyfanswm</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(dim label)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>&amp;Maint</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Label:</translation>
    </message>
    <message>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Gludo cyfeiriad o'r glipfwrdd</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+P</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Neges:</translation>
    </message>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Gludo cyfeiriad o'r glipfwrdd</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+P</translation>
    </message>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation>Dyddiad</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Cyfanswm</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Dyddiad</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Math</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Label</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(dim label)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Today</source>
        <translation>Heddiw</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>Yr wythnos hon</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Y mis hwn</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>Mis diwethaf</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Eleni</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Copïo cyfeiriad</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Copïo label</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Copïo Cyfanswm</translation>
    </message>
    <message>
        <source>Edit label</source>
        <translation>Golygu label</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Cadarnhawyd</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dyddiad</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Math</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Label</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Cyfeiriad</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Methu Allforio</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    <message>
        <source>Close wallet</source>
        <translation>Cau waled</translation>
    </message>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Send Coins</source>
        <translation>Anfon arian</translation>
    </message>
    <message>
        <source>Current fee:</source>
        <translation>Ffi gyfredol</translation>
    </message>
    <message>
        <source>Increase:</source>
        <translation>Cynydd:</translation>
    </message>
    <message>
        <source>New fee:</source>
        <translation>Ffi newydd:</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Allforio</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Allforio'r data yn y tab presennol i ffeil</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    </context>
</TS>